package com.hp.user.service.controller;

import com.baomidou.mybatisplus.extension.api.R;
import com.hp.user.client.entity.*;
import com.hp.user.client.service.AuditService;
import com.hp.user.client.service.CustomerCompanyService;
import com.hp.user.client.service.CustomerServiceProviderEnterpriseService;
import com.hp.user.service.entity.CustomerCompany;
import com.hp.user.service.entity.CustomerServiceProviderEnterprise;
import com.hp.user.service.utils.HttpResult;
import com.hp.user.service.utils.IdWorker;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

@Api(tags = "企业/服务商API接口")
@RestController
@RequestMapping("/company")
public class CompanyController {
    @Autowired
    private CustomerCompanyService customerCompanyService;
    @Autowired
    private AuditService auditService;
    @Autowired
    private CustomerServiceProviderEnterpriseService csService;

    /**
     * 添加企业/服务商
     *
     * @param company 企业/服务商信息
     * @return Result
     */
    @ApiOperation(value = "新增企业/服务商", notes = "提示：要指定审核状态 status；服务商type=0，企业type=1；若新增企业，则需要填serviceProviderIds", httpMethod = "POST")
    @PostMapping("/addCompany")
    @Transactional
    public Result addCompany(@RequestBody CustomerCompanyVO company, String serviceProviderId) {
        company.setCustomerId(IdWorker.generactorId().toString());
        Result result = new Result(), result1 = new Result(), result2 = new Result("0"), result3 = new Result("0");
        result1 = customerCompanyService.insert(company);
        if (serviceProviderId != null) { // 是企业
            CustomerServiceProviderEnterpriseVO temp = new CustomerServiceProviderEnterpriseVO(IdWorker.generactorId().toString(), serviceProviderId, company.getCustomerId());
            result2 = csService.insert(temp);
            AuditVO audit = new AuditVO();
            audit.setAuditId(IdWorker.generactorId().toString());
            audit.setUserId(company.getCustomerId());
            audit.setVipLevel((short) 1); // 普通会员
            audit.setStatus(company.getStatus());
            audit.setIsReply((short) 1); // 未回复
            audit.setFollow((short) 1); // 未跟进
            audit.setPush((short) 1); // 未推送
            result3 = auditService.insert(audit);
        }
        if (result1.getCode().equals("0") && result2.getCode().equals("0") && result3.getCode().equals("0")) {
            result.setCode("0");
            return result;
        } else {
            result.setCode("-1");
            result.setMessage("添加失败");
            return result;
        }
    }
//    public HttpResult addCompany(@RequestBody CustomerCompanyVO company, @RequestBody List<String> serviceProviderIds) {
//        company.setCustomerId(IdWorker.generactorId().toString());
//        boolean flag1 = true, flag2 = true;
//        flag1 = customerCompanyService.insert(company);
//        if (serviceProviderIds != null) {
//            List<CustomerServiceProviderEnterpriseVO> csList=new ArrayList<>();
//            CustomerServiceProviderEnterpriseVO temp;
//            for(String serviceProviderId:serviceProviderIds){
//                temp = new CustomerServiceProviderEnterpriseVO(IdWorker.generactorId().toString(), serviceProviderId, company.getCustomerId());
//                csList.add(temp);
//            }
//            flag2=csService.insertBatch(csList);
//        }
//        if (flag1 && flag2) return HttpResult.success(company.getCustomerId());
//        else return HttpResult.fail("添加失败");
//    }

    /**
     * 更新企业/服务商信息
     *
     * @param company 企业/服务商信息
     * @return Result
     */
    @ApiOperation(value = "更新企业/服务商信息", notes = "若更新企业，则需要填serviceProviderId")
    @PostMapping("/updateCompany")
    @Transactional
    public Result updateCompany(@RequestBody CustomerCompanyVO company, String serviceProviderId) {
        boolean flag1 = true, flag2 = true;
        Result result = new Result(), result1 = new Result(), result2 = new Result("0");
        result1 = customerCompanyService.update(company);
        if (serviceProviderId != null) {
            DataResult temp = csService.queryCsByCompanyId(company.getCustomerId());
            if (temp.getCode().equals("0")) {
                CustomerServiceProviderEnterpriseVO cs = (CustomerServiceProviderEnterpriseVO) temp.getData();
                cs.setServiceProviderId(serviceProviderId);
                result2 = csService.update(cs);
            } else if (temp.getMessage().equals("未查找到企业对应的服务商关系")) {
                CustomerServiceProviderEnterpriseVO tt = new CustomerServiceProviderEnterpriseVO(IdWorker.generactorId().toString(), serviceProviderId, company.getCustomerId());
                result2 = csService.insert(tt);
            } else {
                result.setCode("-1");
                result.setMessage(temp.getMessage());
                return result;
            }
        }
        if (result1.getCode().equals("0") && result2.getCode().equals("0")) {
            result.setCode("0");
            return result;
        } else {
            result.setCode("-1");
            result.setMessage("更新失败");
            return result;
        }
    }

    /**
     * 根据企业Id删除企业
     *
     * @param companyId 企业Id
     * @return Result
     */
    @ApiOperation(value = "删除企业/服务商", notes = "若删除企业，则需要填serviceProviderId")
    @GetMapping("/deleteCompanyByCompanyId")
    public Result deleteCompanyByCompanyId(@RequestParam String companyId, String serviceProviderId) {
        Result result = new Result(), result1, result2;
        result1 = customerCompanyService.delete(companyId);
        if (serviceProviderId != null) { // 删除企业
            DataResult temp = csService.queryCsByCompanyIdAndServiceProviderId(companyId, serviceProviderId);
            if (temp.getCode().equals("0")) {
                CustomerServiceProviderEnterpriseVO cs = (CustomerServiceProviderEnterpriseVO) temp.getData();
                result2 = csService.delete(cs.getId());
            } else {
                result.setCode("-1");
                result.setMessage(temp.getMessage());
                return result;
            }
        } else { // 删除服务商
            result2 = csService.deleteByServiceProviderId(companyId);
        }
        if (result1.getCode().equals("0") && result2.getCode().equals("0")) {
            result.setCode("0");
            return result;
        } else {
            result.setCode("-1");
            result.setMessage("删除失败");
            return result;
        }
    }

    /**
     * 根据企业Id查询某企业信息
     *
     * @param companyId 企业Id
     * @return DataResult
     */
    @ApiOperation(value = "根据企业/服务商Id 查询某企业/服务商信息", notes = "服务商type为0，企业type为1")
    @GetMapping("/queryCompanyByCompanyId")
    public DataResult<CustomerCompanyVO> queryCompanyByCompanyId(@RequestParam String companyId, @RequestParam Integer type) {
        DataResult<CustomerCompanyVO> result = customerCompanyService.queryCompanyByCompanyId(companyId);
        if (result.getCode().equals("0") && type == 1) {
            CustomerCompanyVO temp = result.getData();
            DataResult<CustomerServiceProviderEnterpriseVO> t = csService.queryCsByCompanyId(companyId);
            if (t.getCode().equals("0")) {
                temp.setServiceProviderId(t.getData().getServiceProviderId());
                result.setCode("0");
                result.setData(temp);
            } else if (t.getMessage().equals("未查找到企业对应的服务商关系")) {
                temp.setServiceProviderId(null);
                result.setCode("0");
                result.setData(temp);
            } else {
                result.setCode("-1");
                result.setMessage(t.getMessage());
            }
        }
        return result;
    }

//    /**
//     * 分页查询所有企业信息
//     *
//     * @param current 要查询页数
//     * @param size    一页的行数
//     * @return HttpResult
//     */
//    @ApiOperation(value = "分页查询所有企业/服务商", notes = "输入的current为要查询的页数，size为一页的行数，返回的total为总行数，服务商type为0，企业type为1")
//    @GetMapping("/queryAllCompanyByPage")
//    public HttpResult queryAllCompanyByPage(@RequestParam Long current, @RequestParam Integer size, @RequestParam Integer type) {
//        CompanyPage companyPage = customerCompanyService.getCompanysPage(current, size, type);
//        if (companyPage != null) return HttpResult.success(companyPage);
//        else return HttpResult.fail("查询失败");
//    }

    /**
     * 根据服务商姓名分页查询服务商
     *
     * @param name    服务商名称
     * @param current 要查询页数
     * @param size    一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "根据服务商姓名分页查询服务商")
    @GetMapping("/queryServiceProvidersPageByName")
    public PageResult<CustomerCompanyVO> queryServiceProvidersPageByName(String name, @RequestParam Long current, @RequestParam Integer size) {
        return customerCompanyService.queryServiceProvidersByName(name, current, size);
    }

    /**
     * 分页查询符合条件的企业信息
     *
     * @param name                企业名称
     * @param serviceProviderName 企业关联服务商名称
     * @param status              审核状态
     * @param current             要查询页数
     * @param size                一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "根据企业姓名、关联服务商、审核状态分页查询企业", notes = "审核状态\"全部\"则status=0")
    @GetMapping("/queryCompanysPageByNameAndServiceProviderAndStatus")
    public PageResult<CustomerCompanyVO> queryCompanysPageByNameAndServiceProviderAndStatus(String name, String serviceProviderName, @RequestParam Integer status, @RequestParam Long current, @RequestParam Integer size) {
        return customerCompanyService.queryCompanysPageByNameAndServiceAndStatus(name, serviceProviderName, status, current, size);
    }

    /**
     * 根据服务商Id、企业姓名、审核状态分页查询企业
     *
     * @param serviceProviderId 服务商Id
     * @param name              企业名称
     * @param status            审核状态
     * @param current           要查询页数
     * @param size              一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "根据服务商Id、企业姓名、审核状态分页查询企业", notes = "审核状态\"全部\"则status=0")
    @GetMapping("/queryCompanysPageByServiceProviderIdAndNameAndStatus")
    public PageResult<CustomerCompanyVO> queryCompanysPageByServiceProviderIdAndNameAndStatus(String serviceProviderId, String name, @RequestParam Integer status, @RequestParam Long current, @RequestParam Integer size) {
        return customerCompanyService.queryCompanysPageByServiceProviderIdAndNameAndStatus(serviceProviderId, name, status, current, size);
    }

    /**
     * 微信端，成为合同用户
     *
     * @param company 企业信息
     * @param willing 是否有意向成为合同用户
     * @return Result
     */
    @ApiOperation(value = "成为合同用户", notes = "添加成功会返回添加的企业Id")
    @PostMapping("/becomeContractUser")
    @Transactional
    public Result becomeContractUser(@RequestBody CustomerCompanyVO company, @RequestParam boolean willing) {
        company.setCustomerId(IdWorker.generactorId().toString());
        company.setType((short) 1); // 企业
        company.setStatus((short) 1); // 未审核
        AuditVO audit = new AuditVO();
        audit.setAuditId(IdWorker.generactorId().toString());
        audit.setUserId(company.getCustomerId());
        audit.setStatus((short) 1); // 未审核
        audit.setSource((short) 1); // 来源：维信
        audit.setIsReply((short) 1); // 未回复
        audit.setFollow((short) 1); // 未跟进
        audit.setPush((short) 1); // 未推送
        // 愿意成为合同用户
        if (willing) audit.setVipLevel((short) 1); // 普通会员
        else audit.setVipLevel((short) 2); // 意向用户
        Result result = new Result();
        Result result1 = customerCompanyService.insert(company);
        Result result2 = auditService.insert(audit);
        if (result1.getCode().equals("0") && result2.getCode().equals("0")) {
            result.setCode("0");
            return result;
        } else {
            result.setCode("-1");
            result.setMessage("操作失败");
            return result;
        }
    }

    /**
     * 分页查询所有认证企业
     *
     * @param current 要查询页数
     * @param size    一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "分页查询所有认证企业", notes = "输入的current为要查询的页数，size为一页的行数，返回的total为总行数")
    @GetMapping("/queryAllCompanyCertifyPage")
    public PageResult<CompanyAuditVO> queryAllCompanyCertifyPage(@RequestParam Long current, @RequestParam Integer size) {
        return customerCompanyService.getCompanyAuditsPage(current, size);
    }

    /**
     * 根据企业姓名、审核状态、提交时间分页查询认证企业
     *
     * @param name      企业名称
     * @param status    审核状态
     * @param startTime 提交时间的开始间隔
     * @param endTime   提交时间的结束间隔
     * @param current   要查询的页数
     * @param size      一页的行数
     * @return PageResult
     */
    @ApiOperation(value = "根据企业姓名、审核状态、提交时间分页查询认证企业", notes = "若审核状态为全部，则status填0")
    @GetMapping("/queryCompanysPageByNameAndStatusAndCreateTime")
    public PageResult<CompanyAuditVO> queryCompanysPageByNameAndStatusAndCreateTime(String name, @RequestParam Integer status, Date startTime, Date endTime, @RequestParam Long current, @RequestParam Integer size) {
        return customerCompanyService.queryCompanysPageByNameAndStatusAndCreateTime(name, status, startTime, endTime, current, size);
    }

    /**
     * @param startTime       根据提交时间、企业联系人、联系电话、跟进状态、线索来源、推进状态分页查询合同用户线索
     * @param endTime
     * @param businessContact
     * @param phoneNumber
     * @param follow
     * @param source
     * @param push
     * @param current
     * @param size
     * @return
     */
    @ApiOperation(value = "根据提交时间、企业联系人、联系电话、跟进状态、线索来源、推进状态分页查询合同用户线索", notes = "跟进状态：1:未跟进；2:跟进；推送状态：1:未推送；2:已推送；3:已退回；来源：1：微信小程序；若状态为全部，填0")
    @GetMapping("/queryCluesPageOfContractUser")
    public PageResult<CompanyAuditVO> queryCluesPageOfContractUser(Date startTime, Date endTime, String businessContact, String phoneNumber, @RequestParam Integer follow, @RequestParam Integer source, @RequestParam Integer push, @RequestParam Long current, @RequestParam Integer size) {
        return customerCompanyService.queryCluesPageOfContractUserByCreateTimeAndBusinessContactAndPhoneNumberAndFollowAndSourceAndPush(startTime, endTime, businessContact, phoneNumber, follow, source, push, current, size);
    }

//    public HttpResult queryContectUserByBusinessContectAndPhone

//    /**
//     * 查询某企业的所有用户
//     * @param companyId 企业Id
//     */
//    @GetMapping("/queryAllUserOfCompany")
//    public void queryAllUserOfCompany(String companyId){
//
//    }
//
//    /**
//     * 关联某企业与某用户
//     * @param companyId 企业Id
//     * @param userId 用户Id
//     */
//    @GetMapping("/associateCompanyAndUser")
//    public void associateCompanyAndUser(String companyId,String userId){
//
//    }
//
//    /**
//     * 解除某企业与某用户的关联
//     * @param companyId 企业Id
//     * @param userId 用户Id
//     */
//    @GetMapping("/dissociateCompanyAndUser")
//    public void dissociateCompanyAndUser(String companyId,String userId){
//
//    }
}
